function sumerr = criteria(guess)

% This m-file sets up the objective function to be minimized.

global income qdata qmodel price rho theta nu

rho   = guess(1);
theta = guess(2);
theta = min(theta, .999);

term = ((1-theta)/theta)^(-1/rho);

% Calculate nu
nu =  (income(1) - ( term*price(1)^(1/rho) + price(1) ) * qdata(1) ) / term / price(1)^(1/rho);

% Get number of observations being used
nobs = length(qdata);

% Calculate model's prediction of quantities for computers and consumption
qmodel = zeros(nobs,1);
c = zeros(nobs,1);
check = zeros(nobs,1);
for i=1:nobs
    
    qmodel(i) = computers(price(i), income(i));
    c(i) = ( (1-theta)/theta )^(-1/rho)*price(i)^(1/rho)*( qmodel(i) + nu);
    check(i)  = income(i) - c(i) - price(i)*qmodel(i);
    
end

% Check for errors
if sum(check/nobs) > 1e-10;
    disp('Error in Solution')
end

% Objective function minimizes difference in logs between model and data
sumerr =  log(qdata(2:nobs)) - log(qmodel(2:nobs)) ;
sumerr = sum(sumerr.^2);
 
